Send

Trait Send 

1.0.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

1.26.0 · Source

impl !Send for Args

1.26.0 · Source

impl !Send for ArgsOs

1.0.0 · Source

impl<T> !Send for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for *mut T
where T: ?Sized,

1.25.0 · Source

impl<T> !Send for NonNull<T>
where T: ?Sized,

NonNull pointers are not Send because the data they reference may be aliased.

Source

impl<T> !Send for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for ReentrantLockGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T, A> !Send for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Send for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Send for alloc::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl Send for TypeId

Source

impl Send for core::ffi::c_str::Bytes<'_>

1.10.0 · Source

impl Send for Location<'_>

1.36.0 · Source

impl Send for Waker

1.6.0 · Source

impl Send for fvm_std::prelude::string::Drain<'_>

1.44.0 · Source

impl<'a> Send for IoSlice<'a>

1.44.0 · Source

impl<'a> Send for IoSliceMut<'a>

Source

impl<'a, T, const CAP: usize> Send for arrayvec::arrayvec::Drain<'a, T, CAP>
where T: Send,

Source

impl<Dyn> Send for DynMetadata<Dyn>
where Dyn: ?Sized,

1.0.0 · Source

impl<T> Send for &T
where T: Sync + ?Sized,

Source

impl<T> Send for ThinBox<T>
where T: Send + ?Sized,

ThinBox<T> is Send if T is Send because the data is owned.

1.0.0 · Source

impl<T> Send for alloc::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for alloc::collections::linked_list::IterMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

1.28.0 · Source

impl<T> Send for NonZero<T>

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for core::slice::iter::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for core::slice::iter::IterMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for Atomic<T>
where T: AtomicPrimitive,

Source

impl<T> Send for std::sync::mpmc::Receiver<T>
where T: Send,

Source

impl<T> Send for std::sync::mpmc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Receiver<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for SyncSender<T>
where T: Send,

Source

impl<T> Send for std::sync::nonpoison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

Source

impl<T> Send for std::sync::nonpoison::rwlock::RwLock<T>
where T: Send + ?Sized,

1.70.0 · Source

impl<T> Send for OnceLock<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::poison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

1.0.0 · Source

impl<T> Send for std::sync::poison::rwlock::RwLock<T>
where T: Send + ?Sized,

Source

impl<T> Send for ReentrantLock<T>
where T: Send + ?Sized,

1.29.0 · Source

impl<T> Send for JoinHandle<T>

Source

impl<T, A> Send for Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Send for CursorMut<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for LinkedList<T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for alloc::collections::vec_deque::drain::Drain<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

Source

impl<T, A> Send for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.4.0 · Source

impl<T, A> Send for alloc::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for fvm_std::prelude::vec::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

1.0.0 · Source

impl<T, A> Send for IntoIter<T, A>
where T: Send, A: Allocator + Send,

Auto implementors



impl Send for LogLevel



impl Send for Ordering



impl Send for SearchStep



impl Send for H160



impl Send for H256



impl Send for ParseBoolError



impl Send for Utf8Error



impl Send for FromUtf8Error



impl Send for FromUtf16Error



impl Send for IntoChars



impl Send for String



impl<'a> Send for Utf8Pattern<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for fvm_std::prelude::str::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for EscapeDebug<'a>



impl<'a> Send for EscapeDefault<'a>



impl<'a> Send for EscapeUnicode<'a>



impl<'a> Send for Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>



impl<'a, F> Send for CharPredicateSearcher<'a, F>
where F: Send,



impl<'a, I, A> Send for Splice<'a, I, A>
where I: Send, <I as Iterator>::Item: Send, A: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for Split<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, T, A> Send for PeekMut<'a, T, A>
where A: Send, T: Send,



impl<'a, T, F, A> Send for ExtractIf<'a, T, F, A>
where F: Send, A: Send, T: Send,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>



impl<K, V> Send for HyperMap<K, V>
where K: Send, V: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for HyperList<T>
where T: Send,



impl<T> Send for Event<T>
where T: Send,



impl<T> Send for Reverse<T>
where T: Send,



impl<T, A> Send for Box<T, A>
where A: Send, T: Send + ?Sized,



impl<T, A> Send for Vec<T, A>
where A: Send, T: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,